@@ -1,4 +1,3 @@
-
 detectChangePoint <- function(x,cpmType, ARL0=500,startup=20,lambda=NA) {
     args <- verifyArguments(cpmType,ARL0,startup,lambda)
     if (args$success==FALSE) {
@@ -18,7 +17,7 @@ detectChangePoint <- function(x,cpmType, ARL0=500,startup=20,lambda=NA) {
     res <-.C("cpmDetectChange",as.character(cpmType),as.double(x),as.integer(length(x)),as.double(thresholds),as.integer(length(thresholds)),as.integer(startup),Ds=as.double(numeric(length(x))),cp=as.integer(0),dt=as.integer(0),lambda=as.double(lambda),PACKAGE="cpm")
     dt <- res[["dt"]] 
     if (dt==0) {dt <- length(x)} #needed if no change points are detected
-    return(list(x=x,Ds=res[["Ds"]][1:dt],changePoint=res[["cp"]], detectionTime = res[["dt"]],thresholds=thresholds))
+    return(list(x=x,Ds=res[["Ds"]][1:dt],thresholds=thresholds,changePoint=res[["cp"]], detectionTime = res[["dt"]],changeDetected = res[["dt"]]>0))
 }
 
 
